@@ -34,8 +34,8 @@ namespace api
 class object;
 }
 class list;
-}
-}
+}  // namespace python
+}  // namespace boost
 #endif
 
 namespace Calamares
@@ -60,6 +60,7 @@ public:
 
     /// @brief dump keys and values to the debug log
     void debugDump() const;
+
     /** @brief write as JSON to the given filename
      *
      * No tidying, sanitization, or censoring is done -- for instance,
@@ -69,6 +70,23 @@ public:
      */
     bool save( const QString& filename );
 
+    /** @brief Adds the keys from the given JSON file
+     *
+     * No tidying, sanitization, or censoring is done.
+     * The JSON file is read and each key is added as a value to
+     * the global storage.
+     */
+    bool load( const QString& filename );
+
+    /** @brief write as YAML to the given filename
+     *
+     * See also save(), above.
+     */
+    bool saveYaml( const QString& filename );
+
+    /// @brief reads settings from the given filename
+    bool loadYaml( const QString& filename );
+
 signals:
     void changed();
 
@@ -78,7 +96,7 @@ private:
     friend DebugWindow;
 };
 
-} // namespace Calamares
+}  // namespace Calamares
 
 #ifdef WITH_PYTHON
 namespace CalamaresPython
@@ -106,7 +124,7 @@ private:
     static Calamares::GlobalStorage* s_gs_instance;  // See globalStorageInstance()
 };
 
-} // namespace CalamaresPython
+}  // namespace CalamaresPython
 #endif
 
-#endif // CALAMARES_GLOBALSTORAGE_H
+#endif  // CALAMARES_GLOBALSTORAGE_H
