@@ -26,76 +26,88 @@ namespace CalamaresUtils
 {
 
 /** User defined literals, 1_KiB is 1 KibiByte (= 2^10 bytes) */
-constexpr qint64 operator ""_KiB( unsigned long long m )
+constexpr qint64 operator""_KiB( unsigned long long m )
 {
-    return qint64(m) * 1024;
+    return qint64( m ) * 1024;
 }
 
 /** User defined literals, 1_MiB is 1 MibiByte (= 2^20 bytes) */
-constexpr qint64 operator ""_MiB( unsigned long long m )
+constexpr qint64 operator""_MiB( unsigned long long m )
 {
-    return operator ""_KiB(m) * 1024;
+    return operator""_KiB(m)*1024;
 }
 
 /** User defined literals, 1_GiB is 1 GibiByte (= 2^30 bytes) */
-constexpr qint64 operator ""_GiB( unsigned long long m )
+constexpr qint64 operator""_GiB( unsigned long long m )
 {
-    return operator ""_MiB(m) * 1024;
+    return operator""_MiB(m)*1024;
 }
 
-constexpr qint64 KiBtoBytes( unsigned long long m )
+constexpr qint64
+KiBtoBytes( unsigned long long m )
 {
-    return operator ""_KiB( m );
+    return operator""_KiB( m );
 }
 
-constexpr qint64 MiBtoBytes( unsigned long long m )
+constexpr qint64
+MiBtoBytes( unsigned long long m )
 {
-    return operator ""_MiB( m );
+    return operator""_MiB( m );
 }
 
-constexpr qint64 GiBtoBytes( unsigned long long m )
+constexpr qint64
+GiBtoBytes( unsigned long long m )
 {
-    return operator ""_GiB( m );
+    return operator""_GiB( m );
 }
 
-constexpr qint64 KiBtoBytes( double m )
+constexpr qint64
+KiBtoBytes( double m )
 {
-    return qint64(m * 1024);
+    return qint64( m * 1024 );
 }
 
-constexpr qint64 MiBtoBytes( double m )
+constexpr qint64
+MiBtoBytes( double m )
 {
-    return qint64(m * 1024 * 1024);
+    return qint64( m * 1024 * 1024 );
 }
 
-constexpr qint64 GiBtoBytes( double m )
+constexpr qint64
+GiBtoBytes( double m )
 {
-    return qint64(m * 1024 * 1024 * 1024);
+    return qint64( m * 1024 * 1024 * 1024 );
 }
 
-constexpr int BytesToMiB( qint64 b )
+constexpr int
+BytesToMiB( qint64 b )
 {
     return int( b / 1024 / 1024 );
 }
 
-constexpr int BytesToGiB( qint64 b )
+constexpr int
+BytesToGiB( qint64 b )
 {
     return int( b / 1024 / 1024 / 1024 );
 }
 
-constexpr qint64 alignBytesToBlockSize( qint64 bytes, qint64 blocksize )
+constexpr qint64
+alignBytesToBlockSize( qint64 bytes, qint64 blocksize )
 {
     qint64 blocks = bytes / blocksize;
 
     if ( blocks * blocksize != bytes )
+    {
         ++blocks;
+    }
     return blocks * blocksize;
 }
 
-constexpr qint64 bytesToSectors( qint64 bytes, qint64 blocksize )
+constexpr qint64
+bytesToSectors( qint64 bytes, qint64 blocksize )
 {
-    return alignBytesToBlockSize( alignBytesToBlockSize( bytes, blocksize), MiBtoBytes(1ULL) ) / blocksize;
+    return alignBytesToBlockSize( alignBytesToBlockSize( bytes, blocksize ), MiBtoBytes( 1ULL ) ) / blocksize;
 }
 
-}  // namespace
+}  // namespace CalamaresUtils
 #endif
