@@ -22,7 +22,6 @@
 #define BRANDING_H
 
 #include "UiDllMacro.h"
-#include "Typedefs.h"
 
 #include "utils/NamedSuffix.h"
 
@@ -119,13 +118,29 @@ public:
 
     /** @brief Path to the slideshow QML file, if any. */
     QString slideshowPath() const { return m_slideshowPath; }
+    int slideshowAPI() const { return m_slideshowAPI; }
 
     QString string( Branding::StringEntry stringEntry ) const;
     QString styleString( Branding::StyleEntry styleEntry ) const;
     QString imagePath( Branding::ImageEntry imageEntry ) const;
     QPixmap image( Branding::ImageEntry imageEntry, const QSize& size ) const;
-    /** @brief Stylesheet to apply for this branding. May be empty. */
-    QString stylesheet() const { return m_stylesheet; }
+
+    /** @brief Look up an image in the branding directory or as an icon
+     *
+     * The @p name is checked in the branding directory: if it is an image
+     * file, return the pixmap from that file, at the requested size.
+     * If it isn't a file, look it up as an icon name in the current theme.
+     * May return a null pixmap if nothing is found.
+     */
+    QPixmap image( const QString& name, const QSize& size ) const;
+
+    /** @brief Stylesheet to apply for this branding. May be empty.
+     *
+     * The file is loaded every time this function is called, so
+     * it may be quite expensive -- although normally it will be
+     * called only once, on startup. (Or from the debug window)
+     */
+    QString stylesheet() const;
 
     bool welcomeStyleCalamares() const { return m_welcomeStyleCalamares; }
     bool welcomeExpandingLogo() const { return m_welcomeExpandingLogo; }
@@ -152,14 +167,14 @@ private:
 
     [[noreturn]] void bail( const QString& message );
 
-    QString m_descriptorPath;
-    QString m_componentName;
+    QString m_descriptorPath;  // Path to descriptor (e.g. "/etc/calamares/default/branding.desc")
+    QString m_componentName;  // Matches last part of full path to containing directory
     QMap< QString, QString > m_strings;
     QMap< QString, QString > m_images;
     QMap< QString, QString > m_style;
     QString m_slideshowPath;
+    int m_slideshowAPI;
     QString m_translationsPathPrefix;
-    QString m_stylesheet;  // Text from file
 
     /** @brief Initialize the simple settings below */
     void initSimpleSettings( const YAML::Node& doc );
