@@ -71,7 +71,7 @@ struct LuksDevice
  * Given a list of partitions (as set up by the partitioning module,
  * so there's maps with keys inside), returns just the list of
  * luks passphrases for each device.
- */ 
+ */
 static QList< LuksDevice >
 getLuksDevices( const QVariantList& list )
 {
@@ -130,7 +130,7 @@ static bool
 setupLuks( const LuksDevice& d )
 {
     auto r = CalamaresUtils::System::instance()->targetEnvCommand(
-        { "cryptsetup", "luksAddKey", d.device, keyfile }, QString(), d.passphrase, 15 );
+        { "cryptsetup", "luksAddKey", d.device, keyfile }, QString(), d.passphrase, std::chrono::seconds( 15 ) );
     if ( r.getExitCode() != 0 )
     {
         cWarning() << "Could not configure LUKS keyfile on" << d.device << ':' << r.getOutput() << "(exit code"
