@@ -69,7 +69,7 @@ public:
 
     void setConfigurationMap( const QVariantMap& configurationMap ) override;
 
-    QList< Calamares::job_ptr > jobs() const override;
+    Calamares::JobList jobs() const override;
 
     Calamares::RequirementsList checkRequirements() override;
 
@@ -86,6 +86,8 @@ private:
     QFutureWatcher<void>* m_future;
 
     QSet< PartitionActions::Choices::SwapChoice > m_swapChoices;
+
+    qreal m_requiredStorageGiB;  // May duplicate setting in the welcome module
 };
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( PartitionViewStepFactory )
